@@ -282,11 +282,11 @@ class KinesisStreamsToLambdaProps:
         :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
         '''
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = StreamProps(**kinesis_stream_props)
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
-            sqs_dlq_queue_props = QueueProps(**sqs_dlq_queue_props)
+            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(KinesisStreamsToLambdaProps.__init__)
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
